package org.siddhi.api.condition;

/**
 * 
 * The WhereCondition class contains all the common functionality of the Condition.
 * WhereCondition class is to be extended by all the other Conditions.
 */
public abstract class ExpirableCondition implements Condition {
   private long lifeTime = -1;

    /**
     * This is used for get the life time of a condition in a pattern query
     * @return the lifetime.
     */
    public long getLifeTime() {
        return lifeTime;
    }

    /**
     *  Used to specify the lifetime of a condition in a pattern query
     * @param lifeTime life time of the condition
     */
    public ExpirableCondition within(long lifeTime) {
        this.lifeTime = lifeTime;
        return this;
    }

    /**
     * Used to check whether a life time is set for  the condition in a pattern query
     * @return whether the lifeTime is set for  the condition in a pattern query
     */
    public boolean isLifeTimeSet(){
        if (lifeTime != -1) {
            return true;
        }
        return false;
    }



}
